"""Configuration management."""

from pydantic_settings import BaseSettings


class Settings(BaseSettings):
    soniox_api_key: str = ""
    soniox_api_base_url: str = "https://api.soniox.com"
    default_model: str = "stt-async-v4"
    poll_interval: float = 2.0
    max_poll_attempts: int = 300

    class Config:
        env_file = ".env"
        env_file_encoding = "utf-8"


def get_settings() -> Settings:
    return Settings()
